Welcome to mirror list, hosted at ThFree Co, Russian Federation.

git.blender.org/blender.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorTon Roosendaal <ton@blender.org>2004-01-06 23:25:50 +0300
committerTon Roosendaal <ton@blender.org>2004-01-06 23:25:50 +0300
commite4d0d9cc449b87e9f920b55c1281c3a79a324345 (patch)
tree8a14a1ee08924bdec05f5a8b68c8e85e0462c66f /source/blender/makesdna/DNA_world_types.h
parentbb6a4cf63fb553dce6e6b33887bd8e922fb1407d (diff)
- decided to use a new variable for the new exposure option, instead of
re-using old one. New one = 'exp'. - at first I used the old 'exposure' value, and just mapped it to 0. this causes a problem with upward compatibility, old blenders then render a black picture. is too confusing! - warning; exposure values saved with commit of last week will get lost.
Diffstat (limited to 'source/blender/makesdna/DNA_world_types.h')
-rw-r--r--source/blender/makesdna/DNA_world_types.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/source/blender/makesdna/DNA_world_types.h b/source/blender/makesdna/DNA_world_types.h
index a610d35007a..47ac0d337c3 100644
--- a/source/blender/makesdna/DNA_world_types.h
+++ b/source/blender/makesdna/DNA_world_types.h
@@ -58,10 +58,11 @@ typedef struct World {
unsigned int fastcol;
/**
* New exposure/range control. linfac & logfac are constants... don't belong in
* file, but allocating 8 bytes for temp mem isnt useful either.
*/
- float exposure, range;
+ float exposure, exp, range;
float linfac, logfac;
/**
@@ -93,7 +94,6 @@ typedef struct World {
short dofsta, dofend, dofmin, dofmax;
int physicsEngine;
- int pad;
struct Ipo *ipo;
struct MTex *mtex[8];
@@ -58,10 +58,11 @@ typedef struct World {
unsigned int fastcol;
/**
- * New exposure/range control. linfac & logfac are constants... don't belong in
+ * Exposure= mult factor. unused now, but maybe back later. Kept in to be upward compat.
+ * New is exp/range control. linfac & logfac are constants... don't belong in
* file, but allocating 8 bytes for temp mem isnt useful either.
*/